summaryrefslogtreecommitdiff
path: root/nuttx/drivers/usbhost/usbhost_registerclass.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/drivers/usbhost/usbhost_registerclass.c')
-rw-r--r--nuttx/drivers/usbhost/usbhost_registerclass.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/drivers/usbhost/usbhost_registerclass.c b/nuttx/drivers/usbhost/usbhost_registerclass.c
index f4d1b64af..09d7c7c10 100644
--- a/nuttx/drivers/usbhost/usbhost_registerclass.c
+++ b/nuttx/drivers/usbhost/usbhost_registerclass.c
@@ -83,8 +83,8 @@
* bind a struct usbhost_class_s instance for the device.
*
* Input Parameters:
* class - An write-able instance of struct usbhost_registry_s that will be
* maintained in a registry.
*
* Returned Values:
* On success, this function will return zero (OK). Otherwise, a negated
@@ -92,11 +92,11 @@
*
****************************************************************************/
-int usbhost_registerclass(struct usbhost_registry_s *class)
+int usbhost_registerclass(struct usbhost_registry_s *usbclass)
{
irqstate_t flags;
- uvdbg("Registering class:%p nids:%d\n", class, class->nids);
+ uvdbg("Registering class:%p nids:%d\n", usbclass, usbclass->nids);
/* g_classregistry is a singly-linkedlist of class ID information added by
* calls to usbhost_registerclass(). Since this list is accessed from USB
@@ -108,8 +108,8 @@ int usbhost_registerclass(struct usbhost_registry_s *class)
/* Add the new class ID info to the head of the list */
- class->flink = g_classregistry;
- g_classregistry = class;
+ usbclass->flink = g_classregistry;
+ g_classregistry = usbclass;
irqrestore(flags);
return OK;
@@ -83,8 +83,8 @@
*
* Input Parameters:
- * class - An write-able instance of struct usbhost_registry_s that will be
- * maintained in a registry.
+ * usbclass - An write-able instance of struct usbhost_registry_s that
+ * will be maintained in a registry.
*
* Returned Values: